vfbLib.parsers.base.BaseParser
==============================

.. currentmodule:: vfbLib.parsers.base

.. autoclass:: BaseParser
   :members:
   :show-inheritance:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BaseParser.__init__
      ~BaseParser.parse
      ~BaseParser.parse_hex
      ~BaseParser.read_double
      ~BaseParser.read_doubles
      ~BaseParser.read_int16
      ~BaseParser.read_int32
      ~BaseParser.read_int8
      ~BaseParser.read_str
      ~BaseParser.read_str_all
      ~BaseParser.read_str_with_len
      ~BaseParser.read_uint16
      ~BaseParser.read_uint32
      ~BaseParser.read_uint8
      ~BaseParser.read_value
   
   

   
   
   